kombu.transport.SQS — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# kombu.transport.SQS

Amazon SQS transport.

copyright: | 2010 - 2011 by Ask Solem
license: | BSD, see LICENSE for more details.

- Transport
- Channel

## Transport

class `kombu.transport.SQS.` `Transport`(client, **kwargs)
  class `Channel`(*args, **kwargs)
    class `Table`(connection=None, name=None)

      Amazon SimpleDB domain describing the message routing table.

      `create_binding`(queue)

        Get binding item for queue.

        Creates the item if it doesn’t exist.

      `exchange_delete`(exchange)

        Delete all routes for exchange.

      `get_exchanges`()
      `get_item`(item_name)

        Uses consistent_read by default.

      `get_queue`(queue)

        Get binding for queue.

      `queue_bind`(exchange, routing_key, pattern, queue)
      `queue_delete`(queue)

        delete queue by name.

      `routes_for`(exchange)

        Iterator giving all routes for an exchange.

      `select`(query='', next_token=None, consistent_read=True, max_items=None)

        Uses consistent_read by default.

    `Transport.Channel.` `basic_ack`(delivery_tag)
    `Transport.Channel.` `basic_cancel`(consumer_tag)
    `Transport.Channel.` `basic_consume`(queue, no_ack, *args, **kwargs)
    `Transport.Channel.` `close`()
    `Transport.Channel.` `conninfo`
    `Transport.Channel.` `entity_name`(name, table='x00x01x02x03x04x05x06x07x08tnx0bx0crx0ex0fx10x11x12x13x14x15x16x17x18x19x1ax1bx1cx1dx1ex1f ____________--_0123456789_______ABCDEFGHIJKLMNOPQRSTUVWXYZ______abcdefghijklmnopqrstuvwxyz____x7fx80x81x82x83x84x85x86x87x88x89x8ax8bx8cx8dx8ex8fx90x91x92x93x94x95x96x97x98x99x9ax9bx9cx9dx9ex9fxa0xa1xa2xa3xa4xa5xa6xa7xa8xa9xaaxabxacxadxaexafxb0xb1xb2xb3xb4xb5xb6xb7xb8xb9xbaxbbxbcxbdxbexbfxc0xc1xc2xc3xc4xc5xc6xc7xc8xc9xcaxcbxccxcdxcexcfxd0xd1xd2xd3xd4xd5xd6xd7xd8xd9xdaxdbxdcxddxdexdfxe0xe1xe2xe3xe4xe5xe6xe7xe8xe9xeaxebxecxedxeexefxf0xf1xf2xf3xf4xf5xf6xf7xf8xf9xfaxfbxfcxfdxfexff')

      Format AMQP queue name into a legal SQS queue name.

    `Transport.Channel.` `exchange_delete`(exchange, **kwargs)

      Delete exchange by name.

    `Transport.Channel.` `get_exchanges`()
    `Transport.Channel.` `get_table`(exchange)

      Get routing table.

      Retrieved from SDB if `supports_fanout`.

    `Transport.Channel.` `region`
    `Transport.Channel.` `sdb`
    `Transport.Channel.` `sqs`
    `Transport.Channel.` `supports_fanout`
    `Transport.Channel.` `table`
    `Transport.Channel.` `transport_options`
    `Transport.Channel.` `visibility_timeout`

## Channel

class `kombu.transport.SQS.` `Channel`(*args, **kwargs)
  class `Table`(connection=None, name=None)

    Amazon SimpleDB domain describing the message routing table.

    `create_binding`(queue)

      Get binding item for queue.

      Creates the item if it doesn’t exist.

    `exchange_delete`(exchange)

      Delete all routes for exchange.

    `get_exchanges`()
    `get_item`(item_name)

      Uses consistent_read by default.

    `get_queue`(queue)

      Get binding for queue.

    `queue_bind`(exchange, routing_key, pattern, queue)
    `queue_delete`(queue)

      delete queue by name.

    `routes_for`(exchange)

      Iterator giving all routes for an exchange.

    `select`(query='', next_token=None, consistent_read=True, max_items=None)

      Uses consistent_read by default.

  `Channel.` `basic_ack`(delivery_tag)
  `Channel.` `basic_cancel`(consumer_tag)
  `Channel.` `basic_consume`(queue, no_ack, *args, **kwargs)
  `Channel.` `close`()
  `Channel.` `conninfo`
  `Channel.` `entity_name`(name, table='x00x01x02x03x04x05x06x07x08tnx0bx0crx0ex0fx10x11x12x13x14x15x16x17x18x19x1ax1bx1cx1dx1ex1f ____________--_0123456789_______ABCDEFGHIJKLMNOPQRSTUVWXYZ______abcdefghijklmnopqrstuvwxyz____x7fx80x81x82x83x84x85x86x87x88x89x8ax8bx8cx8dx8ex8fx90x91x92x93x94x95x96x97x98x99x9ax9bx9cx9dx9ex9fxa0xa1xa2xa3xa4xa5xa6xa7xa8xa9xaaxabxacxadxaexafxb0xb1xb2xb3xb4xb5xb6xb7xb8xb9xbaxbbxbcxbdxbexbfxc0xc1xc2xc3xc4xc5xc6xc7xc8xc9xcaxcbxccxcdxcexcfxd0xd1xd2xd3xd4xd5xd6xd7xd8xd9xdaxdbxdcxddxdexdfxe0xe1xe2xe3xe4xe5xe6xe7xe8xe9xeaxebxecxedxeexefxf0xf1xf2xf3xf4xf5xf6xf7xf8xf9xfaxfbxfcxfdxfexff')

    Format AMQP queue name into a legal SQS queue name.

  `Channel.` `exchange_delete`(exchange, **kwargs)

    Delete exchange by name.

  `Channel.` `get_exchanges`()
  `Channel.` `get_table`(exchange)

    Get routing table.

    Retrieved from SDB if `supports_fanout`.

  `Channel.` `region`
  `Channel.` `sdb`
  `Channel.` `sqs`
  `Channel.` `supports_fanout`
  `Channel.` `table`
  `Channel.` `transport_options`
  `Channel.` `visibility_timeout`

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »